/***** interface.c ************************************************
 * Description: Routine for gathering arguments from the command
 *              line.
 * Author: Bernhard Haubold, haubold@evolbio.mpg.de
 * Date: Sun Jun 20 13:12:10 2004.
 *****************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include "interface.h"
#include "eprintf.h"

Args *args;

Args *getArgs(int argc, char *argv[]){
  char c;
  char *optString = "hvi:n:s:m:d:";

  args = (Args *)emalloc(sizeof(Args));
  args->h = 0;
  args->v = 0;
  args->e = 0;
  args->i = DEFAULT_I;
  args->n = DEFAULT_N;
  args->s = 0;
  args->m = DEFAULT_M;
  args->d = DEFAULT_D;

  c = getopt(argc, argv, optString);
  while(c != -1){
    switch(c){
    case 'i':                           /* number of iterations */
      args->i = atoi(optarg);
      break;
    case 'n':                           /* sample size */
      args->n = atoi(optarg);
      break;
    case 's':                           /* seed for random number generator */
      args->s = atoi(optarg);
      break;
    case 'm':                           /* mean */
      args->m = atof(optarg);
      break;
    case 'd':                           /* standard deviation */
      args->d = atof(optarg);
      break;
    case '?':                           /* fall-through is intentional */
    case 'h':                           /* print help */
      args->h = 1;
      break;
    case 'v':                           /* print version */
      args->v = 1;
      break;
    default:
      printf("# unknown argument: %c\n",c);
      args->e = 1;
      return args;
    }
    c = getopt(argc, argv, optString);
  }
  return args;
}


void printUsage(char *version){
  printf("Usage: %s [options] [inputFiles]\n",progname());
  printf("Simulate samples under the normal distribution\n");
  printf("simNorm -n 20\n");
  printf("Options:\n");
  printf("\t[-i <NUM> number of iterations; default: %d]\n", DEFAULT_I);
  printf("\t[-n <NUM> sample size; default: %d]\n", DEFAULT_N);
  printf("\t[-m <NUM> mean; default: %.1f]\n", DEFAULT_M);
  printf("\t[-d <NUM> standard deviation; default: %.1f]\n", DEFAULT_D);
  printf("\t[-s <NUM> seed for random number generator; default: system, randomSeed.dat]\n");
  printf("\t[-h print this help message and exit]\n");
  printf("\t[-v print program information and exit]\n");
  exit(0);
}

void printSplash(char *version){
  printf("%s %s\n",progname(),version);
  printf("Written by Bernhard Haubold.\n");
  printf("Distributed under the GNU General Public License.\n");
  printf("Please send bug reports to haubold@evolbio.mpg.de\n");
  exit(0);
}
